==> nextcloud-12.0.2.tgz: nextcloud/apps/gallery/l10n/pt_BR.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Houve um problema ao ler arquivos deste álbum",
    "Aborting preview. Could not find the file" : "Anulando visualização. Não é possível encontrar o arquivo",
    "Could not move \"{file}\", target exists" : "Não foi possível mover o \"{file}\" pois o destino já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "No compatible server found at {remote}" : "Não foi encontrado nenhum servidor compatível em {remote}",
    "Invalid server url" : "URL inválida de servidor",
    "Could not load the description" : "Não foi possível carregar a descrição",
    "Could not load the description: " : "Não foi possível carregar a descrição:",
    "Copyright" : "Direitos Autorais",
    "Could not load the copyright notice: " : "Não foi possível carregar o aviso de direitos autorais:",
    "Copyright notice" : "Aviso de direitos autorais",
    "Link to copyright document" : "Link para documento de direitos autorais",
    "This application may not work properly on your browser." : "Este aplicativo pode não funcionar corretamente em seu navegador.",
    "For an improved experience, please install one of the following alternatives" : "Para uma melhor experiência, por favor instale uma das seguintes alternativas",
    "Your browser is not supported!" : "Seu navegador não é suportado!",
    "please install one of the following alternatives" : "por favor instale uma das seguintes alternativas",
    "Album cannot be shown" : "O album não pode ser mostrado",
    "No media files found" : "Nenhum arquivo de mídia encontrado",
    "Upload pictures in the Files app to display them here" : "Enviar imagens no aplicativo Arquivos para exibi-las aqui",
    "Upload new files via drag and drop or by using the [+] button above" : "Envie novos arquivos ao arrastar e soltar ou usando o botão [+] acima",
    "Configuration error" : "Erro de configuração",
    "New" : "Novo",
    "Hide Album" : "Ocultar Álbum",
    "Could not hide album" : "Não foi possível ocultar o álbum",
    "Error loading slideshow template" : "Erro ao carregar o modelo de slideshow",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erro!</strong> Não foi possível gerar uma visualização desse arquivo.<br>Por favor, vá para o próximo slide enquanto removemos esta imagem da apresentação de slides",
    "Next" : "Próximo",
    "Play" : "Reproduzir",
    "Pause" : "Pausa",
    "Previous" : "Anterior",
    "Close" : "Fechar",
    "Download" : "Baixar",
    "Toggle background" : "Alternar fundo",
    "Delete" : "Excluir",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" pois ele já existe",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar vazio.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "Upload" : "Enviar",
    "Error" : "Erro",
    "Error while sharing" : "Erro ao compartilhar",
    "Error while unsharing" : "Erro ao descompartilhar",
    "Error while changing permissions" : "Erro ao mudar permissões",
    "Shared with you and the group {group} by {owner}" : "Compartilhado com você e com o grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartilhado com você por {owner}",
    "Share with users or groups …" : "Compartilhar com usuários ou grupos...",
    "Share with users, groups or remote users …" : "Compartilhar com usuários, grupos ou usuários remoto...",
    "Share" : "Compartilhar",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Compartilhe com pessoas em outros servidores usando o ID federado username@example.com/cloud",
    "Share link" : "Compartilhar link",
    "The public link will expire no later than {days} days after it is created" : "O link público irá expirar não antes de {days} depois de ser criado",
    "Link" : "Link",
    "Password protect" : "Proteger com senha",
    "Password" : "Senha",
    "Choose a password for the public link" : "Defina uma senha para o link público",
    "Allow editing" : "Permitir edição",
    "Email link to person" : "Enviar link por e-mail",
    "Send" : "Enviar",
    "Set expiration date" : "Definir data de expiração",
    "Expiration" : "Expiração",
    "Expiration date" : "Data de expiração",
    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista pode estar truncada - por favor refine os termos da pesquisa para mais resultados.",
    "No users or groups found for {search}" : "Nenhum usuário ou grupo encontrado para {search}",
    "No users found for {search}" : "Nenhum usuário encontrado para {search}",
    "An error occured. Please try again" : "Ocorreu um erro. Por favor tente novamente",
    "Adding user..." : "Adicionando usuário...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Não é permitido recompartilhar",
    "Error while retrieving shares" : "Erro ao recuperar compartilhamentos",
    "Unshare" : "Descompartilhar",
    "notify by email" : "notificar por e-mail",
    "can share" : "pode compartilhar",
    "can edit" : "pode editar",
    "access control" : "controle de acesso",
    "create" : "criar",
    "change" : "mudança",
    "delete" : "excluir",
    "Password protected" : "Protegido com senha",
    "Error unsetting expiration date" : "Erro ao remover data de expiração",
    "Error setting expiration date" : "Erro ao definir data de expiração",
    "Sending ..." : "Enviando...",
    "Email sent" : "E-mail enviado",
    "Warning" : "Aviso",
    "This share is password-protected" : "Este compartilhamento está protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Sort by date" : "Ordenar por data",
    "Sort by name" : "Ordenar por nome",
    "Cancel upload" : "Cancelar envio",
    "Album information" : "Informações do álbum",
    "File list" : "Lista de arquivo",
    "Sorry, this file could not be found." : "Desculpe, este arquivo não pôde ser encontrado.",
    "Reasons might be:" : "As razões podem ser:",
    "the wrong file ID was provided" : "foi fornecida uma ID errada de arquivo",
    "the file was removed" : "o arquivo foi excluído",
    "the file is corrupt" : "o arquivo está corrompido",
    "the encryption key is missing" : "está faltando a chave de criptografia",
    "Here is the error message returned by the server: " : "Aqui está a mensagem de erro retornada pelo servidor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Para mais informações, por favor contacte o administrador",
    "Sorry, but the server could not fulfill your request." : "Desculpe, mas o servidor não pôde completar a sua solicitação.",
    "Possible reasons for the problem:" : "Possíveis razões para o problema:",
    "a conflicting app was installed" : "um aplicativo conflitante foi instalado",
    "a required component is missing or was disconnected" : "um componente necessário está faltando ou foi desconectado",
    "the filesystem is not readable" : "o sistema de arquivos não está legível",
    "Sorry, this link doesn't seem to work anymore." : "Desculpe, este link parece não funcionar mais.",
    "the item was removed" : "o item foi excluído",
    "the link has expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more information, please ask the person who has sent you this link." : "Para mais informações, pergunte à pessoa que lhe enviou o link.",
    "Add to your Nextcloud" : "Adicionar ao seu Nextcloud",
    "Picture view" : "Visualização de imagem",
    "Gallery view" : "Vista da  galeria"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/pt_BR.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Houve um problema ao ler arquivos deste álbum",
    "Aborting preview. Could not find the file" : "Anulando visualização. Não é possível encontrar o arquivo",
    "Could not move \"{file}\", target exists" : "Não foi possível mover o \"{file}\" pois o destino já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "No compatible server found at {remote}" : "Não foi encontrado nenhum servidor compatível em {remote}",
    "Invalid server url" : "URL inválida de servidor",
    "Could not load the description" : "Não foi possível carregar a descrição",
    "Could not load the description: " : "Não foi possível carregar a descrição:",
    "Copyright" : "Direitos Autorais",
    "Could not load the copyright notice: " : "Não foi possível carregar o aviso de direitos autorais:",
    "Copyright notice" : "Aviso de direitos autorais",
    "Link to copyright document" : "Link para documento de direitos autorais",
    "This application may not work properly on your browser." : "Este aplicativo pode não funcionar corretamente em seu navegador.",
    "For an improved experience, please install one of the following alternatives" : "Para uma melhor experiência, por favor instale uma das seguintes alternativas",
    "Your browser is not supported!" : "Seu navegador não é suportado!",
    "please install one of the following alternatives" : "por favor instale uma das seguintes alternativas",
    "Album cannot be shown" : "O album não pode ser mostrado",
    "No media files found" : "Nenhum arquivo de mídia encontrado",
    "Upload pictures in the Files app to display them here" : "Enviar imagens no aplicativo Arquivos para exibi-las aqui",
    "Upload new files via drag and drop or by using the [+] button above" : "Envie novos arquivos ao arrastar e soltar ou usando o botão [+] acima",
    "Configuration error" : "Erro de configuração",
    "New" : "Novo",
    "Hide Album" : "Ocultar Álbum",
    "Could not hide album" : "Não foi possível ocultar o álbum",
    "Error loading slideshow template" : "Erro ao carregar o modelo de slideshow",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erro!</strong> Não foi possível gerar uma visualização desse arquivo.<br>Por favor, vá para o próximo slide enquanto removemos esta imagem da apresentação de slides",
    "Next" : "Próximo",
    "Play" : "Reproduzir",
    "Pause" : "Pausa",
    "Previous" : "Anterior",
    "Close" : "Fechar",
    "Download" : "Baixar",
    "Toggle background" : "Alternar fundo",
    "Delete" : "Excluir",
    "Share" : "Compartilhar",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" pois ele já existe",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar vazio.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "Upload" : "Enviar",
    "Error" : "Erro",
    "Error while sharing" : "Erro ao compartilhar",
    "Error while unsharing" : "Erro ao descompartilhar",
    "Error while changing permissions" : "Erro ao mudar permissões",
    "Shared with you and the group {group} by {owner}" : "Compartilhado com você e com o grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartilhado com você por {owner}",
    "Share with users or groups …" : "Compartilhar com usuários ou grupos...",
    "Share with users, groups or remote users …" : "Compartilhar com usuários, grupos ou usuários remoto...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Compartilhe com pessoas em outros servidores usando o ID federado username@example.com/cloud",
    "Share link" : "Compartilhar link",
    "The public link will expire no later than {days} days after it is created" : "O link público irá expirar não antes de {days} depois de ser criado",
    "Link" : "Link",
    "Password protect" : "Proteger com senha",
    "Password" : "Senha",
    "Choose a password for the public link" : "Defina uma senha para o link público",
    "Allow editing" : "Permitir edição",
    "Email link to person" : "Enviar link por e-mail",
    "Send" : "Enviar",
    "Set expiration date" : "Definir data de expiração",
    "Expiration" : "Expiração",
    "Expiration date" : "Data de expiração",
    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista pode estar truncada - por favor refine os termos da pesquisa para mais resultados.",
    "No users or groups found for {search}" : "Nenhum usuário ou grupo encontrado para {search}",
    "No users found for {search}" : "Nenhum usuário encontrado para {search}",
    "An error occured. Please try again" : "Ocorreu um erro. Por favor tente novamente",
    "Adding user..." : "Adicionando usuário...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Não é permitido recompartilhar",
    "Error while retrieving shares" : "Erro ao recuperar compartilhamentos",
    "Unshare" : "Descompartilhar",
    "notify by email" : "notificar por e-mail",
    "can share" : "pode compartilhar",
    "can edit" : "pode editar",
    "access control" : "controle de acesso",
    "create" : "criar",
    "change" : "mudança",
    "delete" : "excluir",
    "Password protected" : "Protegido com senha",
    "Error unsetting expiration date" : "Erro ao remover data de expiração",
    "Error setting expiration date" : "Erro ao definir data de expiração",
    "Sending…" : "Enviando...",
    "Email sent" : "E-mail enviado",
    "Warning" : "Aviso",
    "This share is password-protected" : "Este compartilhamento está protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Sort by name" : "Ordenar por nome",
    "Sort by date" : "Ordenar por data",
    "Cancel upload" : "Cancelar envio",
    "Album information" : "Informações do álbum",
    "File list" : "Lista de arquivo",
    "Sorry, this file could not be found." : "Desculpe, este arquivo não pôde ser encontrado.",
    "Reasons might be:" : "As razões podem ser:",
    "the wrong file ID was provided" : "foi fornecida uma ID errada de arquivo",
    "the file was removed" : "o arquivo foi excluído",
    "the file is corrupt" : "o arquivo está corrompido",
    "the encryption key is missing" : "está faltando a chave de criptografia",
    "Here is the error message returned by the server: " : "Aqui está a mensagem de erro retornada pelo servidor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Para mais informações, por favor contacte o administrador",
    "Sorry, but the server could not fulfill your request." : "Desculpe, mas o servidor não pôde completar a sua solicitação.",
    "Possible reasons for the problem:" : "Possíveis razões para o problema:",
    "a conflicting app was installed" : "um aplicativo conflitante foi instalado",
    "a required component is missing or was disconnected" : "um componente necessário está faltando ou foi desconectado",
    "the filesystem is not readable" : "o sistema de arquivos não está legível",
    "Sorry, this link doesn't seem to work anymore." : "Desculpe, este link parece não funcionar mais.",
    "the item was removed" : "o item foi excluído",
    "the link has expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more information, please ask the person who has sent you this link." : "Para mais informações, pergunte à pessoa que lhe enviou o link.",
    "Add to your Nextcloud" : "Adicionar ao seu Nextcloud",
    "Picture view" : "Visualização de imagem",
    "Gallery view" : "Vista da  galeria",
    "Sending ..." : "Enviando..."
},
"nplurals=2; plural=(n > 1);");
